==> lonewolf4m_0.1.1.tar.gz: lonewolf4m-0.1.1/core/item.h <==
#ifndef ITEM_H
#define ITEM_H

#include <QObject>
#include <QHash>
#include <QScriptEngine>

class PropertiesItem : public QObject
{
    Q_OBJECT

public:
    explicit PropertiesItem(QObject *parent = 0);
    PropertiesItem(const PropertiesItem& item);

    QHash<QString, QString> Properties;

public slots:
    QString GetProperty(QString name);
    void SetProperty(QString name, QString value);
    bool GetBoolProperty(QString name) { return GetProperty(name).toInt() == 1;}
    void SetBoolProperty(QString name, bool value) { SetProperty(name, value ? "1" : "0"); }
};



class Item : public PropertiesItem
{
    Q_OBJECT
public:
    explicit Item(QObject *parent = 0);
    Item(const Item& item);

    QString Name;
    QString Description;

    bool IsUsable() { return GetIsMeal() || GetEnduranceRestore(); }
    void Use(QScriptEngine* engine, QScriptValue* functions);

public slots:
    QString GetName() { return Name; }
    bool GetIsBackpackItem() { return !GetIsSpecial() && !GetIsWeapon(); }

    bool GetIsSpecial() { return GetBoolProperty("IsSpecial"); }
    void SetIsSpecial(bool value) { SetBoolProperty("IsSpecial", value); }

    bool GetIsBackpack() { return GetBoolProperty("IsBackpack"); }
    void SetIsBackpack(bool value) { SetBoolProperty("IsBackpack", value); }

    bool GetIsMeal() { return GetBoolProperty("IsMeal"); }
    void SetIsMeal(bool value) { SetBoolProperty("IsMeal", value); }

    int GetEnduranceRestore() { return GetProperty("EnduranceRestore").toInt(); }
    void SetEnduranceRestore(int value) { SetProperty("EnduranceRestore", QString::number(value)); }

    int GetEnduranceDelta() { return GetProperty("EnduranceDelta").toInt(); }
    void SetEnduranceDelta(int value) { SetProperty("EnduranceDelta", QString::number(value)); }

    QString GetDescription() { return Description; }
    void SetDescription(QString value) { Description = value; }

    int GetCombatskillDelta() { return GetProperty("CombatskillDelta").toInt(); }
    void SetCombatskillDelta(int value) { SetProperty("CombatskillDelta", QString::number(value)); }

    int GetQuantity() { return GetProperty("Quantity").toInt(); }
    void SetQuantity(int value) { SetProperty("Quantity", QString::number(value)); }

    int GetSize() { return GetProperty("Size").toInt(); }
    void SetSize(int value) { SetProperty("Size", QString::number(value)); }

    bool GetIsEquipped() { return GetBoolProperty("IsEquipped"); }
    void SetIsEquipped(bool value) { SetBoolProperty("IsEquipped", value); }
    void Equip() { SetIsEquipped(true); }
    void Unequip() { SetIsEquipped(false); }

    bool GetIsWeapon() { return GetBoolProperty("IsWeapon"); }
    void SetIsWeapon(bool value) { SetBoolProperty("IsWeapon", value); }

    bool GetIsArmor() { return GetBoolProperty("IsArmor"); }
    void SetIsArmor(bool value) { SetBoolProperty("IsArmor", value); }

    int GetHands() { return GetProperty("Hands").toInt(); }
    void SetHands(int value) { SetProperty("Hands", QString::number(value)); }

    int GetArmorPlace() { return GetProperty("Place").toInt(); }
    void SetArmorPlace(int value) { SetProperty("Place", QString::number(value)); }
};

class Weapon : public Item
{
    Q_OBJECT
public:
    enum WeaponsClass
    {
       None = -1,
       Dagger,
       Spear,
       Mace,
       ShortSword,
       WarHammer,
       Axe,
       Sword,
       Quarterstaff,
       Broadsword
    };

    explicit Weapon(QObject *parent = 0);
    Weapon(const Weapon& weapon);

    static QString ClassDescription(int Class);
    static int GetClass(QString);

public slots:
    QList<int> Classes();
    void AddClass(int iClass);
};

class ShopItem : public Weapon
{
    Q_OBJECT
public:
    explicit ShopItem(QObject *parent = 0);

    int Price;
    int SellPrice;
    bool UnlimitedQuantity;

    bool IsWeapon() { return Classes().count() > 0; }
};

class Armor : public Item
{
    Q_OBJECT
public:
    enum ArmorPlace
    {
       None = -1,
       Head,
       Body,
       Hand
    };

    explicit Armor(QObject *parent = 0);
    Armor(const Armor& armor);

    static int GetPlace(QString);

public slots:
    int Place();
    void SetPlace(int iPlace);
};

#endif // ITEM_H

==> lonewolf4m_0.1.2.tar.gz: lonewolf4m-0.1.2/core/item.h <==
#ifndef ITEM_H
#define ITEM_H

#include <QObject>
#include <QHash>
#include <QScriptEngine>

class PropertiesItem : public QObject
{
    Q_OBJECT

public:
    explicit PropertiesItem(QObject *parent = 0);
    PropertiesItem(const PropertiesItem& item);

    QHash<QString, QString> Properties;

public slots:
    QString GetProperty(QString name);
    void SetProperty(QString name, QString value);
    bool GetBoolProperty(QString name) { return GetProperty(name).toInt() == 1;}
    void SetBoolProperty(QString name, bool value) { SetProperty(name, value ? "1" : "0"); }
};



class Item : public PropertiesItem
{
    Q_OBJECT
public:
    explicit Item(QObject *parent = 0);
    Item(const Item& item);

    QString Name;
    QString Description;

    bool IsUsable() { return GetIsMeal() || GetEnduranceRestore(); }
    void Use(QScriptEngine* engine, QScriptValue* functions);

public slots:
    QString GetName() { return Name; }
    bool GetIsBackpackItem() { return !GetIsSpecial() && !GetIsWeapon(); }

    bool GetIsSpecial() { return GetBoolProperty("IsSpecial"); }
    void SetIsSpecial(bool value) { SetBoolProperty("IsSpecial", value); }

    bool GetIsBackpack() { return GetBoolProperty("IsBackpack"); }
    void SetIsBackpack(bool value) { SetBoolProperty("IsBackpack", value); }

    bool GetIsMeal() { return GetBoolProperty("IsMeal"); }
    void SetIsMeal(bool value) { SetBoolProperty("IsMeal", value); }

    int GetEnduranceRestore() { return GetProperty("EnduranceRestore").toInt(); }
    void SetEnduranceRestore(int value) { SetProperty("EnduranceRestore", QString::number(value)); }

    int GetEnduranceDelta() { return GetProperty("EnduranceDelta").toInt(); }
    void SetEnduranceDelta(int value) { SetProperty("EnduranceDelta", QString::number(value)); }

    QString GetDescription() { return Description; }
    void SetDescription(QString value) { Description = value; }

    int GetCombatskillDelta() { return GetProperty("CombatskillDelta").toInt(); }
    void SetCombatskillDelta(int value) { SetProperty("CombatskillDelta", QString::number(value)); }

    int GetQuantity() { return GetProperty("Quantity").toInt(); }
    void SetQuantity(int value) { SetProperty("Quantity", QString::number(value)); }

    int GetSize() { return GetProperty("Size").toInt(); }
    void SetSize(int value) { SetProperty("Size", QString::number(value)); }

    bool GetIsEquipped() { return GetBoolProperty("IsEquipped"); }
    void SetIsEquipped(bool value) { SetBoolProperty("IsEquipped", value); }
    void Equip() { if (GetCanBeEquipped()) SetIsEquipped(true); }
    void Unequip() { SetIsEquipped(false); }

    bool GetIsWeapon() { return GetBoolProperty("IsWeapon"); }
    void SetIsWeapon(bool value) { SetBoolProperty("IsWeapon", value); }

    bool GetCanBeEquipped() { return GetBoolProperty("CanBeEquipped"); }
    void SetCanBeEquipped(bool value);

    bool GetIsArmor() { return GetBoolProperty("IsArmor"); }
    void SetIsArmor(bool value) { SetBoolProperty("IsArmor", value); }

    int GetHands() { return GetProperty("Hands").toInt(); }
    void SetHands(int value) { SetProperty("Hands", QString::number(value)); }

    int GetArmorPlace() { return GetProperty("Place").toInt(); }
    void SetArmorPlace(int value) { SetProperty("Place", QString::number(value)); }
};

class Weapon : public Item
{
    Q_OBJECT
public:
    enum WeaponsClass
    {
       None = -1,
       Dagger,
       Spear,
       Mace,
       ShortSword,
       WarHammer,
       Axe,
       Sword,
       Quarterstaff,
       Broadsword
    };

    explicit Weapon(QObject *parent = 0);
    Weapon(const Weapon& weapon);

    static QString ClassDescription(int Class);
    static int GetClass(QString);

public slots:
    QList<int> Classes();
    void AddClass(int iClass);
};

class ShopItem : public Weapon
{
    Q_OBJECT
public:
    explicit ShopItem(QObject *parent = 0);

    int Price;
    int SellPrice;
    bool UnlimitedQuantity;

    bool IsWeapon() { return Classes().count() > 0; }
};

class Armor : public Item
{
    Q_OBJECT
public:
    enum ArmorPlace
    {
       None = -1,
       Head,
       Body,
       Hand
    };

    explicit Armor(QObject *parent = 0);
    Armor(const Armor& armor);

    static int GetPlace(QString);

public slots:
    int Place();
    void SetPlace(int iPlace);
};

#endif // ITEM_H
